"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateReferrerFee = exports.fetchStatus = exports.fetchSignedQuote = exports.fetchCapabilities = exports.RequestPrefix = exports.RelayStatus = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const axios_1 = __importDefault(require("axios"));
const consts_js_1 = require("./consts.js");
const types_js_1 = require("../types.js");
var RelayStatus;
(function (RelayStatus) {
    RelayStatus["Pending"] = "pending";
    RelayStatus["Failed"] = "failed";
    RelayStatus["Unsupported"] = "unsupported";
    RelayStatus["Submitted"] = "submitted";
    RelayStatus["Underpaid"] = "underpaid";
    RelayStatus["Aborted"] = "aborted";
})(RelayStatus || (exports.RelayStatus = RelayStatus = {}));
var RequestPrefix;
(function (RequestPrefix) {
    RequestPrefix["ERM1"] = "ERM1";
    RequestPrefix["ERV1"] = "ERV1";
    RequestPrefix["ERN1"] = "ERN1";
    RequestPrefix["ERC1"] = "ERC1";
    RequestPrefix["ERC2"] = "ERC2";
})(RequestPrefix || (exports.RequestPrefix = RequestPrefix = {}));
async function fetchCapabilities(network) {
    const url = `${consts_js_1.apiBaseUrl[network]}/v0/capabilities`;
    try {
        const response = await axios_1.default.get(url);
        return response.data;
    }
    catch (error) {
        throw new Error(`Failed to fetch capabilities for network: ${network}.`);
    }
}
exports.fetchCapabilities = fetchCapabilities;
async function fetchSignedQuote(network, srcChain, dstChain, relayInstructions // TODO: `0x:${string}`
) {
    const url = `${consts_js_1.apiBaseUrl[network]}/v0/quote`;
    try {
        const response = await axios_1.default.post(url, {
            srcChain: (0, sdk_base_1.toChainId)(srcChain),
            dstChain: (0, sdk_base_1.toChainId)(dstChain),
            relayInstructions,
        });
        return response.data;
    }
    catch (error) {
        throw new Error(`Failed to fetch signed quote.`);
    }
}
exports.fetchSignedQuote = fetchSignedQuote;
// Fetch Status
async function fetchStatus(network, txHash, chain) {
    const url = `${consts_js_1.apiBaseUrl[network]}/v0/status/tx`;
    try {
        const response = await axios_1.default.post(url, {
            txHash,
            chainId: (0, sdk_base_1.toChainId)(chain),
        });
        return response.data;
    }
    catch (error) {
        throw new Error(`Failed to fetch status for txHash: ${txHash}.`);
    }
}
exports.fetchStatus = fetchStatus;
const MAX_U16 = 65535n;
function calculateReferrerFee(_amount, dBps, destinationTokenDecimals) {
    if (dBps > MAX_U16) {
        throw new Error("dBps exceeds max u16");
    }
    const amount = sdk_base_1.amount.units(_amount);
    let remainingAmount = amount;
    let referrerFee = 0n;
    if (dBps > 0) {
        referrerFee = (amount * dBps) / 100000n;
        // The NttManagerWithExecutor trims the fee before subtracting it from the amount
        const trimmedFee = types_js_1.NttRoute.trimAmount(sdk_base_1.amount.fromBaseUnits(referrerFee, _amount.decimals), destinationTokenDecimals);
        remainingAmount = amount - sdk_base_1.amount.units(trimmedFee);
    }
    return { referrerFee, remainingAmount, referrerFeeDbps: dBps };
}
exports.calculateReferrerFee = calculateReferrerFee;
//# sourceMappingURL=utils.js.map