import { Chain, ChainAddress, ChainContext, Network, Signer, TokenId, TransactionId, TransferReceipt as _TransferReceipt, Wormhole, amount, routes, Platform } from "@wormhole-foundation/sdk-connect";
import "@wormhole-foundation/sdk-definitions-ntt";
import { NttRoute } from "../types.js";
import { Ntt, NttWithExecutor } from "@wormhole-foundation/sdk-definitions-ntt";
export declare namespace NttExecutorRoute {
    type Config = {
        ntt: NttRoute.Config;
        referrerFee?: ReferrerFeeConfig;
    };
    type ReferrerFeeConfig = {
        feeDbps: bigint;
        referrerAddresses?: Partial<Record<Platform, string>>;
        perTokenOverrides?: Partial<Record<Chain, Record<string, {
            referrerFeeDbps: bigint;
        }>>>;
    };
    type Options = {
        nativeGas?: number;
    };
    type NormalizedParams = {
        amount: amount.Amount;
        sourceContracts: Ntt.Contracts;
        destinationContracts: Ntt.Contracts;
        referrerFeeDbps: bigint;
    };
    interface ValidatedParams extends routes.ValidatedTransferParams<Options> {
        normalizedParams: NormalizedParams;
    }
    type TransferReceipt<SC extends Chain = Chain, DC extends Chain = Chain> = _TransferReceipt<NttRoute.ManualAttestationReceipt, SC, DC> & {
        params: ValidatedParams;
    };
}
type Op = NttExecutorRoute.Options;
type Tp = routes.TransferParams<Op>;
type Vr = routes.ValidationResult<Op>;
type Vp = NttExecutorRoute.ValidatedParams;
type Q = routes.Quote<Op, Vp, NttWithExecutor.Quote>;
type QR = routes.QuoteResult<Op, Vp>;
type R = NttExecutorRoute.TransferReceipt;
export declare function nttExecutorRoute(config: NttExecutorRoute.Config): {
    new <N extends "Mainnet" | "Testnet" | "Devnet">(wh: Wormhole<N>): {
        readonly staticConfig: NttExecutorRoute.Config;
        getDefaultOptions(): NttExecutorRoute.Options;
        validate(request: routes.RouteTransferRequest<N>, params: Tp): Promise<Vr>;
        quote(request: routes.RouteTransferRequest<N>, params: NttExecutorRoute.ValidatedParams): Promise<QR>;
        fetchExecutorQuote(request: routes.RouteTransferRequest<N>, params: NttExecutorRoute.ValidatedParams): Promise<NttWithExecutor.Quote>;
        initiate(request: routes.RouteTransferRequest<N>, signer: Signer, quote: Q, to: ChainAddress): Promise<R>;
        complete(signer: Signer, receipt: R): Promise<R>;
        resume(tx: TransactionId): Promise<R>;
        finalize(signer: Signer, receipt: R): Promise<R>;
        track(receipt: R, timeout?: number | undefined): AsyncGenerator<R, void, unknown>;
        wh: Wormhole<N>;
        transferUrl(txid: string): string;
    };
    config: NttExecutorRoute.Config;
    NATIVE_GAS_DROPOFF_SUPPORTED: boolean;
    meta: {
        name: string;
    };
    supportedNetworks(): ("Mainnet" | "Testnet" | "Devnet")[];
    supportedChains(network: "Mainnet" | "Testnet" | "Devnet"): ("Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia")[];
    supportedSourceTokens(fromChain: ChainContext<"Mainnet" | "Testnet" | "Devnet", "Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia", import("@wormhole-foundation/sdk-connect").ChainToPlatform<"Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia">>): Promise<TokenId[]>;
    supportedDestinationTokens<N_1 extends "Mainnet" | "Testnet" | "Devnet">(sourceToken: TokenId, fromChain: ChainContext<N_1, "Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia", import("@wormhole-foundation/sdk-connect").ChainToPlatform<"Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia">>, toChain: ChainContext<N_1, "Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia", import("@wormhole-foundation/sdk-connect").ChainToPlatform<"Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia">>): Promise<TokenId[]>;
    isProtocolSupported<N_2 extends "Mainnet" | "Testnet" | "Devnet">(chain: ChainContext<N_2, "Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia", import("@wormhole-foundation/sdk-connect").ChainToPlatform<"Solana" | "Ethereum" | "Bsc" | "Polygon" | "Avalanche" | "Algorand" | "Fantom" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Btc" | "Base" | "Sei" | "Scroll" | "Mantle" | "Blast" | "Xlayer" | "Linea" | "Berachain" | "Seievm" | "Snaxchain" | "Unichain" | "Worldchain" | "Ink" | "HyperEVM" | "Monad" | "Mezo" | "Sonic" | "Converge" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Seda" | "Dymension" | "Provenance" | "Noble" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "PolygonSepolia">>): boolean;
    IS_AUTOMATIC: boolean;
};
export declare class NttExecutorRoute<N extends Network> extends routes.AutomaticRoute<N, Op, Vp, R> implements routes.StaticRouteMethods<typeof NttExecutorRoute> {
    static NATIVE_GAS_DROPOFF_SUPPORTED: boolean;
    readonly staticConfig: NttExecutorRoute.Config;
    static config: NttExecutorRoute.Config;
    static meta: {
        name: string;
    };
    static supportedNetworks(): Network[];
    static supportedChains(network: Network): Chain[];
    static supportedSourceTokens(fromChain: ChainContext<Network>): Promise<TokenId[]>;
    static supportedDestinationTokens<N extends Network>(sourceToken: TokenId, fromChain: ChainContext<N>, toChain: ChainContext<N>): Promise<TokenId[]>;
    static isProtocolSupported<N extends Network>(chain: ChainContext<N>): boolean;
    getDefaultOptions(): Op;
    validate(request: routes.RouteTransferRequest<N>, params: Tp): Promise<Vr>;
    quote(request: routes.RouteTransferRequest<N>, params: Vp): Promise<QR>;
    fetchExecutorQuote(request: routes.RouteTransferRequest<N>, params: Vp): Promise<NttWithExecutor.Quote>;
    initiate(request: routes.RouteTransferRequest<N>, signer: Signer, quote: Q, to: ChainAddress): Promise<R>;
    complete(signer: Signer, receipt: R): Promise<R>;
    resume(tx: TransactionId): Promise<R>;
    finalize(signer: Signer, receipt: R): Promise<R>;
    track(receipt: R, timeout?: number): AsyncGenerator<R, void, unknown>;
}
export {};
//# sourceMappingURL=executor.d.ts.map